/**
 * 用于存储小程序页面实例，更新页面值
 */
const instanceKey = Symbol("instance");

type WXinstance = WechatMiniprogram.Page.Instance<
   Record<string, unknown>,
   Record<string, unknown>
>;

class InstanceStore {
   private [instanceKey]: Array<WXinstance>;

   constructor() {
      // 事件储存
      this[instanceKey] = [];
   }

   /**
    * 新增监听页面/组件
    * @param {*} instance 页面/组件实例
    */
   push(instance: WXinstance) {
      this[instanceKey].push(instance);
   }

   /**
    * 移除监听
    * @param {*} instance 页面/组件实例
    */
   remove(instance: WXinstance) {
      this[instanceKey] = this[instanceKey].filter((ins) => ins !== instance);
   }

   /**
    * 更新实例数据
    * @param {*} stateKey 需要更新的键
    * @param {*} stateValue 值
    */
   update(stateKey: string, stateValue: unknown) {
      this[instanceKey].forEach((instance) => {
         instance.setData({
            [stateKey]: stateValue,
         });
      });
   }
}

export const instanceStore = new InstanceStore();
